/*
 * Ext JS Library 2.1
 * Copyright(c) 2006-2008, Ext JS, LLC.
 * licensing@extjs.com
 * 
 * http://extjs.com/license
 */

Ext.UpdateManager.defaults.indicatorText="<div class=\"loading-indicator\">U�?itavanje...</div>";if(Ext.View){Ext.View.prototype.emptyText=""}if(Ext.grid.Grid){Ext.grid.Grid.prototype.ddText="{0} odabranih redova"}if(Ext.TabPanelItem){Ext.TabPanelItem.prototype.closeText="Zatvori ovaj tab"}if(Ext.form.Field){Ext.form.Field.prototype.invalidText="Unesena vrijednost u ovom polju je neispravna"}if(Ext.LoadMask){Ext.LoadMask.prototype.msg="U�?itavanje..."}Date.monthNames=["Sije�?anj","Velja�?a","Ožujak","Travanj","Svibanj","Lipanj","Srpanj","Kolovoz","Rujan","Listopad","Studeni","Prosinac"];Date.dayNames=["Nedjelja","Ponedjeljak","Utorak","Srijeda","Četvrtak","Petak","Subota"];if(Ext.MessageBox){Ext.MessageBox.buttonText={ok:"U redu",cancel:"Odustani",yes:"Da",no:"Ne"}}if(Ext.util.Format){Ext.util.Format.date=function(A,B){if(!A){return""}if(!(A instanceof Date)){A=new Date(Date.parse(A))}return A.dateFormat(B||"d.m.Y")}}if(Ext.DatePicker){Ext.apply(Ext.DatePicker.prototype,{todayText:"Danas",minText:"Taj datum je prije najmanjeg datuma",maxText:"Taj datum je poslije najvećeg datuma",disabledDaysText:"",disabledDatesText:"",monthNames:Date.monthNames,dayNames:Date.dayNames,nextText:"Slijedeći mjesec (Control+Desno)",prevText:"Prethodni mjesec (Control+Lijevo)",monthYearText:"Odaberite mjesec (Control+Gore/Dolje za promjenu godine)",todayTip:"{0} (Razmaknica)",format:"d.m.y",startDay:1})}if(Ext.PagingToolbar){Ext.apply(Ext.PagingToolbar.prototype,{beforePageText:"Stranica",afterPageText:"od {0}",firstText:"Prva stranica",prevText:"Prethodna stranica",nextText:"Slijedeća stranica",lastText:"Posljednja stranica",refreshText:"Obnovi",displayMsg:"Prikazujem {0} - {1} od {2}",emptyMsg:"Nema podataka za prikaz"})}if(Ext.form.TextField){Ext.apply(Ext.form.TextField.prototype,{minLengthText:"Minimalna dužina za ovo polje je {0}",maxLengthText:"Maksimalna dužina za ovo polje je {0}",blankText:"Ovo polje je obavezno",regexText:"",emptyText:null})}if(Ext.form.NumberField){Ext.apply(Ext.form.NumberField.prototype,{minText:"Minimalna vrijednost za ovo polje je {0}",maxText:"Maksimalna vrijednost za ovo polje je {0}",nanText:"{0} nije ispravan broj"})}if(Ext.form.DateField){Ext.apply(Ext.form.DateField.prototype,{disabledDaysText:"Neaktivno",disabledDatesText:"Neaktivno",minText:"Datum u ovom polje mora biti poslije {0}",maxText:"Datum u ovom polju mora biti prije {0}",invalidText:"{0} nije ispravan datum - mora biti u obliku {1}",format:"d.m.y"})}if(Ext.form.ComboBox){Ext.apply(Ext.form.ComboBox.prototype,{loadingText:"U�?itavanje...",valueNotFoundText:undefined})}if(Ext.form.VTypes){Ext.apply(Ext.form.VTypes,{emailText:"Ovdje možete unijeti samo e-mail adresu u obliku \"korisnik@domena.com\"",urlText:"Ovdje možete unijeti samo URL u obliku \"http:/"+"/www.domena.com\"",alphaText:"Ovo polje može sadržavati samo slova i znak _",alphanumText:"Ovo polje može sadržavati samo slova, brojeve i znak _"})}if(Ext.grid.GridView){Ext.apply(Ext.grid.GridView.prototype,{sortAscText:"Sortiraj rastućim redoslijedom",sortDescText:"Sortiraj padajućim redoslijedom",lockText:"Zaklju�?aj stupac",unlockText:"Otklju�?aj stupac",columnsText:"Stupci"})}if(Ext.grid.PropertyColumnModel){Ext.apply(Ext.grid.PropertyColumnModel.prototype,{nameText:"Naziv",valueText:"Vrijednost",dateFormat:"d.m.Y"})}if(Ext.layout.BorderLayout.SplitRegion){Ext.apply(Ext.layout.BorderLayout.SplitRegion.prototype,{splitTip:"Povuci za promjenu veli�?ine.",collapsibleSplitTip:"Povuci za promjenu veli�?ine. Dvostruki klik za skrivanje."})};